@@ -149,20 +149,28 @@ class HiYaPyCo():
 
         for yamlfile in self._files:
             logger.debug('yamlfile: %s ...' % yamlfile)
-            fn = yamlfile
-            if not os.path.isabs(yamlfile):
-                fn = os.path.join(os.getcwd(), yamlfile)
-                logger.debug('path extended for yamlfile: %s' % fn)
-            try:
-                f = open(fn, 'r')
-            except IOError as e:
-                logger.log(self.loglevelonmissingfiles, e)
-                if not fn == yamlfile:
-                    logger.log(self.loglevelonmissingfiles, 'file not found: %s (%s)' % (yamlfile, fn,))
-                else:
-                    logger.log(self.loglevelonmissingfiles, 'file not found: %s' % yamlfile)
-                if self.failonmissingfiles:
-                    raise HiYaPyCoInvocationException('yaml file not found: \'%s\'' % yamlfile )
+            if '\n' in yamlfile:
+                logger.debug('loading yaml doc from str ...')
+                f = yamlfile
+            else:
+                fn = yamlfile
+                if not os.path.isabs(yamlfile):
+                    fn = os.path.join(os.getcwd(), yamlfile)
+                    logger.debug('path extended for yamlfile: %s' % fn)
+                try:
+                    f = open(fn, 'r')
+                except IOError as e:
+                    logger.log(self.loglevelonmissingfiles, e)
+                    if not fn == yamlfile:
+                        logger.log(self.loglevelonmissingfiles,
+                                'file not found: %s (%s)' % (yamlfile, fn,))
+                    else:
+                        logger.log(self.loglevelonmissingfiles,
+                                'file not found: %s' % yamlfile)
+                    if self.failonmissingfiles:
+                        raise HiYaPyCoInvocationException(
+                                'yaml file not found: \'%s\'' % yamlfile
+                            )
             if _usedefaultyamlloader:
                 ydata = yaml.safe_load(f)
             else:
